@@ -1,29 +1,28 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#    Copyright (C) 2011 Cédric Krier
-
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2011 Cédric Krier <cedric.krier@b2ck.com>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                    HEALTH CONTACT TRACING package                     #
+#                      setup.py: Setuptools file                        #
+#########################################################################
 from setuptools import setup
 import re
 import os
 import configparser
 
+
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
+    return open(os.path.join(os.path.dirname(__file__), fname),
+                encoding="UTF-8").read()
+
 
 config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
@@ -41,19 +40,23 @@ for dep in info.get('depends', []):
         requires.append('gnuhealth == %s' % (info.get('version')))
 
     elif dep.startswith('health_'):
-        health_package = dep.split('_',1)[1]
+        health_package = dep.split('_', 1)[1]
         requires.append('gnuhealth_%s == %s' %
-            (health_package, info.get('version')))
-    else: 
+                        (health_package, info.get('version')))
+    else:
         if not re.match(r'(ir|res|webdav)(\W|$)', dep):
-            requires.append('trytond_%s >= %s.%s, < %s.%s' %
+            requires.append(
+                'trytond_%s >= %s.%s, < %s.%s' %
                 (dep, major_version, minor_version, major_version,
                     minor_version + 1))
 
-setup(name='gnuhealth_contact_tracing',
+setup(
+    name='gnuhealth_contact_tracing',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', 'GNU Health package for epidemics contact tracing'),
-    long_description=read('README'),
+    description=info.get(
+        'description',
+        'GNU Health package for epidemics contact tracing'),
+    long_description=read('README.rst'),
     author='GNU Solidario',
     author_email='health@gnusolidario.org',
     url='https://www.gnuhealth.org',
@@ -65,10 +68,10 @@ setup(name='gnuhealth_contact_tracing',
         ],
 
     package_data={
-        'trytond.modules.health_contact_tracing': info.get('xml', []) \
-            + info.get('translation', []) \
-            + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
-               'report/*.fodt', 'icons/*.svg'],
+        'trytond.modules.health_contact_tracing': info.get('xml', [])
+        + info.get('translation', [])
+        + ['tryton.cfg', 'view/*.xml', 'doc/*.rst', 'locale/*.po',
+           'report/*.fodt', 'icons/*.svg'],
         },
 
     classifiers=[
