@@ -1,5 +1,8 @@
-# This file is part of GNU Health.  The COPYRIGHT file at the top level of
-# this repository contains the full copyright notices and license terms.
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from trytond.exceptions import UserError, UserWarning
 
 
@@ -15,7 +18,7 @@ class ThalamusConnectionError(UserError):
     pass
 
 
-class ThalamusConnectionOK(UserWarning):
+class ThalamusConnectionOK(UserError):
     pass
 
 
